@@ -1,4 +1,7 @@
 import os
+import re
+import subprocess
+import sys
 import time
 
 from .common import FileDownloader
@@ -49,6 +52,8 @@ class HttpFD(FileDownloader):
         while count <= retries:
             # Establish connection
             try:
+                if count == 0 and 'urlhandle' in info_dict:
+                    data = info_dict['urlhandle']
                 data = compat_urllib_request.urlopen(request)
                 break
             except (compat_urllib_error.HTTPError, ) as err:
@@ -133,7 +138,7 @@ class HttpFD(FileDownloader):
                     return False
             try:
                 stream.write(data_block)
-            except (IOError, OSError) as err:
+            except (IOError, OSError):
                 self.to_stderr(u"\n")
                 self.report_error(u'unable to write data: %s' % str(err))
                 return False
