@@ -1434,8 +1434,12 @@ class YoutubeIE(YoutubeBaseInfoExtractor, SubtitlesInfoExtractor):
             })
 
         def _formats_key(f):
+            note = f.get('format_note')
+            if note is None:
+                note = u''
+            is_dash = u'DASH' in note
             return (
-                0 if 'DASH' in f.get('format_note', '') else 1,
+                0 if is_dash else 1,
                 f.get('height') if f.get('height') is not None else -1,
                 f.get('width') if f.get('width') is not None else -1)
         formats.sort(key=_formats_key)
